# Generated by Django 4.1.4 on 2024-07-31 15:42

from django.db import migrations
from django.db import models


def create_settings_object(apps, schema_editor):
    settings = apps.get_model('b3integration_mig24', 'SettingsMig24')
    settings.objects.create()


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ('integrations_market', '__latest__'),
    ]

    operations = [
        migrations.CreateModel(
            name='SettingsMig24',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'verbose_name': 'Настройки',
                'verbose_name_plural': 'Настройки',
            },
        ),
        migrations.RunPython(create_settings_object),
    ]
